import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/pager-item/vue';
import { IconPopup, IconDoubleLeft, IconDoubleRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "pager-group": "inline-block align-middle text-xs h-7 leading-7",
  "li": "bg-transparent inline-flex items-center justify-center text-xs ml-2 cursor-pointer text-center h-7 min-w-[theme(spacing.7)] text-color-text-primary py-0 px-1 box-border transition-all duration-500 ease-linear border border-solid border-transparent rounded",
  "li-hover": "hover:text-color-brand-hover hover:bg-color-border-disabled",
  "is-active": "text-color-brand bg-color-fill-6 hover:bg-color-fill-6",
  "quick-icon": "w-4 h-4 align-text-top fill-color-icon-primary hover:fill-color-brand cursor-pointer",
  "dot": "w-4 min-w-0 p-0 border-none hover:bg-color-fill-6"
};
var __vue2_script = defineComponent({
  emits: ["click", "change"],
  components: {
    IconPopup: IconPopup(),
    IconDoubleLeft: IconDoubleLeft(),
    IconDoubleRight: IconDoubleRight()
  },
  props: [].concat(props, ["disabled", "currentPage", "pageCount", "pagerCount", "popupIcon", "doubleLeftIcon", "doubleRightIcon", "isBeforePageChange"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: _vm.gcls("pager-group"),
    attrs: {
      "data-tag": "tiny-pager-item"
    }
  }, [_c("ul", {
    staticClass: "hidden sm:inline-flex text-xs",
    attrs: {
      "data-tag": "pager-item-content"
    },
    on: {
      "click": _vm.onPagerClick
    }
  }, [_vm.pageCount > 0 ? _c("li", {
    class: _vm.m(_vm.gcls("li"), _vm.gcls("li-hover"), _vm.gcls({
      "is-active": _vm.currentPage === 1
    })),
    attrs: {
      "data-tag": "pager-item-hover"
    },
    domProps: {
      "textContent": _vm._s("1")
    }
  }) : _vm._e(), _vm.state.showPrevMore ? _c("li", {
    ref: "prev",
    class: _vm.m(_vm.gcls("li"), _vm.gcls("dot"), "dot quickprev"),
    attrs: {
      "data-tag": "pager-item-premore"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.onMouseenter("left");
      },
      "mouseleave": function mouseleave($event) {
        _vm.state.quickprevIconClass = _vm.popupIcon;
      }
    }
  }, [_c(_vm.state.quickprevIconClass, {
    tag: "component",
    class: _vm.gcls("quick-icon")
  })], 1) : _vm._e(), _vm._l(_vm.state.pagers, function(pager) {
    return _c("li", {
      key: pager,
      class: _vm.m(_vm.gcls("li"), _vm.gcls("li-hover"), _vm.gcls({
        "is-active": _vm.currentPage === pager
      })),
      attrs: {
        "data-tag": "pager-item-pager"
      },
      domProps: {
        "textContent": _vm._s("" + pager)
      }
    });
  }), _vm.state.showNextMore ? _c("li", {
    ref: "next",
    class: _vm.m(_vm.gcls("li"), _vm.gcls("dot"), "dot quicknext"),
    attrs: {
      "data-tag": "pager-item-nextmore"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.onMouseenter("right");
      },
      "mouseleave": function mouseleave($event) {
        _vm.state.quicknextIconClass = _vm.popupIcon;
      }
    }
  }, [_c(_vm.state.quicknextIconClass, {
    tag: "component",
    class: _vm.gcls("quick-icon")
  })], 1) : _vm._e(), _vm.pageCount > 1 ? _c("li", {
    staticClass: "hover:text-color-brand-hover",
    class: _vm.m(_vm.gcls("li"), _vm.gcls({
      "is-active": _vm.pageCount === _vm.currentPage
    })),
    attrs: {
      "data-tag": "pager-item-active"
    },
    domProps: {
      "textContent": _vm._s("" + _vm.pageCount)
    }
  }) : _vm._e()], 2), _c("li", {
    staticClass: "h-7 text-color-text-primary sm:hidden flex items-center justify-center rounded !mx-4"
  }, [_c("span", {
    staticClass: "inline-block my-0 mx-0"
  }, [_vm._v(_vm._s(_vm.currentPage) + " / " + _vm._s(_vm.pageCount))])])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
