import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/pager-item/vue';
import { iconPopup, iconDoubleLeft, iconDoubleRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "PagerItem",
  emits: ["click", "change"],
  components: {
    IconPopup: iconPopup(),
    IconDoubleLeft: iconDoubleLeft(),
    IconDoubleRight: iconDoubleRight()
  },
  props: {
    disabled: {
      type: Boolean,
      default: false
    },
    currentPage: Number,
    pageCount: Number,
    pagerCount: Number,
    popupIcon: {
      type: Object,
      default: function _default() {
        return iconPopup();
      }
    },
    doubleLeftIcon: {
      type: Object,
      default: function _default2() {
        return iconDoubleLeft();
      }
    },
    doubleRightIcon: {
      type: Object,
      default: function _default3() {
        return iconDoubleRight();
      }
    },
    isBeforePageChange: Boolean
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-pager__group tiny-unselect"
  }, [_c("ul", {
    staticClass: "tiny-pager__pages",
    on: {
      "click": _vm.onPagerClick
    }
  }, [_vm.pageCount > 0 ? _c("li", {
    class: {
      "is-active": _vm.currentPage === 1
    },
    domProps: {
      "textContent": _vm._s("1")
    }
  }) : _vm._e(), _vm.state.showPrevMore ? _c("li", {
    ref: "prev",
    staticClass: "dot quickprev",
    class: [_vm.state.quickprevIconClass === _vm.popupIcon && "is-popup"],
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.onMouseenter("left");
      },
      "mouseleave": function mouseleave($event) {
        _vm.state.quickprevIconClass = _vm.popupIcon;
      }
    }
  }, [_c(_vm.state.quickprevIconClass, {
    tag: "component"
  })], 1) : _vm._e(), _vm._l(_vm.state.pagers, function(pager) {
    return _c("li", {
      key: pager,
      class: {
        "is-active": _vm.currentPage === pager
      },
      domProps: {
        "textContent": _vm._s("" + pager)
      }
    });
  }), _vm.state.showNextMore ? _c("li", {
    ref: "next",
    staticClass: "dot quicknext",
    class: [_vm.state.quicknextIconClass === _vm.popupIcon && "is-popup"],
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.onMouseenter("right");
      },
      "mouseleave": function mouseleave($event) {
        _vm.state.quicknextIconClass = _vm.popupIcon;
      }
    }
  }, [_c(_vm.state.quicknextIconClass, {
    tag: "component"
  })], 1) : _vm._e(), _vm.pageCount > 1 ? _c("li", {
    class: {
      "is-active": _vm.pageCount === _vm.currentPage
    },
    domProps: {
      "textContent": _vm._s("" + _vm.pageCount)
    }
  }) : _vm._e()], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
